@@ -29,6 +29,7 @@ from pulp_ansible.app.galaxy.v3.serializers import (
     CollectionVersionDocsSerializer,
     CollectionVersionListSerializer,
     RepoMetadataSerializer,
+    UnpaginatedCollectionVersionSerializer,
 )
 from pulp_ansible.app.models import (
     AnsibleCollectionDeprecated,
@@ -95,6 +96,10 @@ class CollectionVersionRetrieveMixin:
         """
         Returns a CollectionVersions queryset for specified distribution.
         """
+        if not self.request and not self.args and not self.kwargs:
+            # drf_spectacular get filter from get_queryset().model
+            # and it fails when "path" is not on self.kwargs
+            return CollectionVersion.objects.none()
         distro_content = self._distro_content
 
         collections = CollectionVersion.objects.select_related(
@@ -172,6 +177,10 @@ class CollectionViewSet(
         """
         Returns a Collections queryset for specified distribution.
         """
+        if not self.request and not self.args and not self.kwargs:
+            # drf_spectacular get filter from get_queryset().model
+            # and it fails when "path" is not on self.kwargs
+            return Collection.objects.none()
         repo_version = self._repository_version
         return Collection.objects.filter(
             versions__in=repo_version.content,
@@ -272,7 +281,7 @@ class CollectionViewSet(
         super_data = super().get_serializer_context()
         if getattr(self, "available_versions_context", None):
             super_data["available_versions"] = self.available_versions_context
-        super_data["deprecated_collections"] = self.deprecated_collections_context
+        super_data["deprecated_collections"] = getattr(self, "deprecated_collections_context", [])
         return super_data
 
     def update(self, request, *args, **kwargs):
@@ -381,11 +390,19 @@ class CollectionVersionViewSet(
     authentication_classes = []
     permission_classes = []
     serializer_class = CollectionVersionSerializer
+    list_serializer_class = CollectionVersionListSerializer
     filterset_class = CollectionVersionFilter
     pagination_class = LimitOffsetPagination
 
     lookup_field = "version"
 
+    def get_list_serializer(self, *args, **kwargs):
+        """
+        Return the list serializer instance.
+        """
+        kwargs.setdefault("context", self.get_serializer_context)
+        return self.list_serializer_class(*args, **kwargs)
+
     def list(self, request, *args, **kwargs):
         """
         Returns paginated CollectionVersions list.
@@ -398,16 +415,17 @@ class CollectionVersionViewSet(
         context = self.get_serializer_context()
         page = self.paginate_queryset(queryset)
         if page is not None:
-            serializer = CollectionVersionListSerializer(page, many=True, context=context)
+            serializer = self.get_list_serializer(page, many=True, context=context)
             return self.get_paginated_response(serializer.data)
 
-        serializer = CollectionVersionListSerializer(queryset, many=True, context=context)
+        serializer = self.get_list_serializer(queryset, many=True, context=context)
         return Response(serializer.data)
 
 
 class UnpaginatedCollectionVersionViewSet(CollectionVersionViewSet):
     """Unpaginated ViewSet for CollectionVersions."""
 
+    serializer_class = UnpaginatedCollectionVersionSerializer
     pagination_class = None
 
     def get_queryset(self):
@@ -432,10 +450,10 @@ class UnpaginatedCollectionVersionViewSet(CollectionVersionViewSet):
         context = self.get_serializer_context()
         page = self.paginate_queryset(queryset)
         if page is not None:
-            serializer = CollectionVersionSerializer(page, many=True, context=context)
+            serializer = self.get_serializer(page, many=True, context=context)
             return self.get_paginated_response(serializer.data)
 
-        serializer = CollectionVersionSerializer(queryset, many=True, context=context)
+        serializer = self.get_serializer(queryset, many=True, context=context)
         return Response(serializer.data)
 
 
