@@ -39,6 +39,7 @@ v2_urls = [
 ]
 
 v3_urls = [
+    path("", views_v3.RepoMetadataViewSet.as_view({"get": "retrieve"}), name="repo-metadata"),
     path(
         "collections/", views_v3.CollectionViewSet.as_view({"get": "list"}), name="collections-list"
     ),
@@ -72,6 +73,16 @@ v3_urls = [
         views_v3.CollectionImportViewSet.as_view({"get": "retrieve"}),
         name="collection-imports-detail",
     ),
+    path(
+        "collections/all/",
+        views_v3.UnpaginatedCollectionViewSet.as_view({"get": "list"}),
+        name="metadata-collection-list",
+    ),
+    path(
+        "collection_versions/all/",
+        views_v3.UnpaginatedCollectionVersionViewSet.as_view({"get": "list"}),
+        name="metadata-collection-versions-list",
+    ),
 ]
 
 urlpatterns = [
