@@ -7,9 +7,10 @@ import unittest
 from pulpcore.client.pulp_ansible import (
     DistributionsAnsibleApi,
     RepositoriesAnsibleApi,
-    RepositorySyncURL,
+    AnsibleRepositorySyncURL,
     RemotesCollectionApi,
 )
+from pulp_smash.pulp3.bindings import monitor_task
 from pulp_smash.pulp3.utils import gen_distribution, gen_repo
 
 from pulp_ansible.tests.functional.constants import (
@@ -17,11 +18,7 @@ from pulp_ansible.tests.functional.constants import (
     ANSIBLE_DEMO_COLLECTION_REQUIREMENTS as DEMO_REQUIREMENTS,
     GALAXY_ANSIBLE_BASE_URL,
 )
-from pulp_ansible.tests.functional.utils import (
-    gen_ansible_client,
-    gen_ansible_remote,
-    monitor_task,
-)
+from pulp_ansible.tests.functional.utils import gen_ansible_client, gen_ansible_remote
 from pulp_ansible.tests.functional.utils import set_up_module as setUpModule  # noqa:F401
 
 
@@ -46,7 +43,7 @@ class InstallCollectionTestCase(unittest.TestCase):
 
         # Sync the repository.
         self.assertEqual(repo.latest_version_href, f"{repo.pulp_href}versions/0/")
-        repository_sync_data = RepositorySyncURL(remote=remote.pulp_href)
+        repository_sync_data = AnsibleRepositorySyncURL(remote=remote.pulp_href)
         sync_response = self.repo_api.sync(repo.pulp_href, repository_sync_data)
         monitor_task(sync_response.task)
         repo = self.repo_api.read(repo.pulp_href)
@@ -55,8 +52,8 @@ class InstallCollectionTestCase(unittest.TestCase):
         body = gen_distribution()
         body["repository"] = repo.pulp_href
         distribution_create = self.distributions_api.create(body)
-        distribution_url = monitor_task(distribution_create.task)
-        distribution = self.distributions_api.read(distribution_url[0])
+        created_resources = monitor_task(distribution_create.task).created_resources
+        distribution = self.distributions_api.read(created_resources[0])
 
         self.addCleanup(self.distributions_api.delete, distribution.pulp_href)
 
