@@ -1,9 +1,11 @@
 """Utilities for tests for the ansible plugin."""
+from dynaconf import Dynaconf
 from functools import partial
 from time import sleep
 import unittest
 
 from pulp_smash import api, config, selectors
+from pulp_smash.pulp3.bindings import monitor_task
 from pulp_smash.pulp3.utils import (
     gen_distribution,
     gen_remote,
@@ -35,7 +37,8 @@ from pulpcore.client.pulp_ansible import (
     PulpAnsibleGalaxyApiV3VersionsApi,
     RepositoriesAnsibleApi,
     RemotesCollectionApi,
-    RepositorySyncURL,
+    RemotesRoleApi,
+    AnsibleRepositorySyncURL,
 )
 
 
@@ -59,6 +62,9 @@ def gen_ansible_remote(url=ANSIBLE_FIXTURE_URL, **kwargs):
 
     :param url: The URL of an external content source.
     """
+    if "rate_limit" not in kwargs:
+        kwargs["rate_limit"] = 10
+
     return gen_remote(url, **kwargs)
 
 
@@ -125,30 +131,6 @@ core_client = CoreApiClient(configuration)
 tasks = TasksApi(core_client)
 
 
-def monitor_task(task_href):
-    """Polls the Task API until the task is in a completed state.
-
-    Prints the task details and a success or failure message. Exits on failure.
-
-    Args:
-        task_href(str): The href of the task to monitor
-
-    Returns:
-        list[str]: List of hrefs that identify resource created by the task
-
-    """
-    completed = ["completed", "failed", "canceled"]
-    task = tasks.read(task_href)
-    while task.state not in completed:
-        sleep(1)
-        task = tasks.read(task_href)
-
-    if task.state == "completed":
-        return task.created_resources
-
-    return task.to_dict()
-
-
 def wait_tasks():
     """Polls the Task API until all tasks are in a completed state."""
     running_tasks = tasks.list(state="running")
@@ -166,6 +148,7 @@ class TestCaseUsingBindings(unittest.TestCase):
         cls.client = gen_ansible_client()
         cls.repo_api = RepositoriesAnsibleApi(cls.client)
         cls.remote_collection_api = RemotesCollectionApi(cls.client)
+        cls.remote_role_api = RemotesRoleApi(cls.client)
         cls.distributions_api = DistributionsAnsibleApi(cls.client)
         cls.cv_api = ContentCollectionVersionsApi(cls.client)
         cls.collections_v3api = PulpAnsibleGalaxyApiCollectionsApi(cls.client)
@@ -186,7 +169,7 @@ class SyncHelpersMixin:
             repository: The created repository object to be asserted to.
         """
         # Create the repository.
-        repo = self.repo_api.create(gen_repo())
+        repo = self.repo_api.create(gen_repo(remote=remote.pulp_href))
         self.addCleanup(self.repo_api.delete, repo.pulp_href)
         return self._sync_repo(repo, remote=remote.pulp_href)
 
@@ -215,7 +198,7 @@ class SyncHelpersMixin:
         Returns:
             repository: The updated repository after the sync is complete
         """
-        repository_sync_data = RepositorySyncURL(**kwargs)
+        repository_sync_data = AnsibleRepositorySyncURL(**kwargs)
         sync_response = self.repo_api.sync(repo.pulp_href, repository_sync_data)
         monitor_task(sync_response.task)
         repo = self.repo_api.read(repo.pulp_href)
@@ -235,7 +218,29 @@ class SyncHelpersMixin:
         body = gen_distribution()
         body["repository"] = repo.pulp_href
         distribution_create = self.distributions_api.create(body)
-        distribution_url = monitor_task(distribution_create.task)
-        distribution = self.distributions_api.read(distribution_url[0])
+        created_resources = monitor_task(distribution_create.task).created_resources
+        distribution = self.distributions_api.read(created_resources[0])
         self.addCleanup(self.distributions_api.delete, distribution.pulp_href)
         return distribution
+
+
+settings = Dynaconf(
+    settings_files=["pulp_ansible/tests/assets/func_test_settings.py", "/etc/pulp/settings.py"]
+)
+
+
+def get_psql_smash_cmd(sql_statement):
+    """
+    Generate a command in a format for pulp smash cli client to execute the specified SQL statement.
+
+    The implication is that PostgreSQL is always running on localhost.
+    Args:
+        sql_statement(str): An SQL statement to execute.
+    Returns:
+        tuple: a command in the format for  pulp smash cli client
+    """
+    host = "localhost"
+    user = settings.DATABASES["default"]["USER"]
+    password = settings.DATABASES["default"]["PASSWORD"]
+    dbname = settings.DATABASES["default"]["NAME"]
+    return ("psql", "-c", sql_statement, f"postgresql://{user}:{password}@{host}/{dbname}")
